==> mktcenter-service-2.0.0-20200323.084943-42-sources.jar: com/bizvane/mktcenterservice/models/bo/OrderModelBo.java <==
package com.bizvane.mktcenterservice.models.bo;

import java.math.BigDecimal;
import java.util.Date;

/**
 * Created by agan on 2018/7/28.
 */
public class OrderModelBo {

    private String memberCode;//会员编号

    private Long brandId;//品牌id

    private Integer orderFrom;//订单来源

    private BigDecimal payMoney;//订单金额

    private String productNos;//商品编码

    private Long serviceStoreId;//服务门店id

    private Long mbrServiceStoreId;//服务门店id

    private Long levelId;//会员等级id

    private Integer memberType;//会员范围

    private Long companyId;//企业id

    private Integer orderBasePoint ;

    private Date orderTime;

    private Integer activityType;

    private String orderNum;

    //退单的订单时间
    private Date backOrderTime;

    private String tag;

    private String remark;

    public Long getCompanyId() {
        return companyId;
    }

    public void setCompanyId(Long companyId) {
        this.companyId = companyId;
    }

    public String getProductNos() {
        return productNos;
    }

    public void setProductNos(String productNos) {
        this.productNos = productNos;
    }

    public Integer getMemberType() {
        return memberType;
    }

    public void setMemberType(Integer memberType) {
        this.memberType = memberType;
    }

    public BigDecimal getPayMoney() {
        return payMoney;
    }

    public void setPayMoney(BigDecimal payMoney) {
        this.payMoney = payMoney;
    }

    public String getMemberCode() {
        return memberCode;
    }

    public void setMemberCode(String memberCode) {
        this.memberCode = memberCode;
    }

    public Integer getOrderFrom() {
        return orderFrom;
    }

    public void setOrderFrom(Integer orderFrom) {
        this.orderFrom = orderFrom;
    }

    public Long getServiceStoreId() {
        return serviceStoreId;
    }

    public void setServiceStoreId(Long serviceStoreId) {
        this.serviceStoreId = serviceStoreId;
    }

    public Long getLevelId() {
        return levelId;
    }

    public void setLevelId(Long levelId) {
        this.levelId = levelId;
    }

    public Integer getOrderBasePoint() {
        return orderBasePoint;
    }

    public void setOrderBasePoint(Integer orderBasePoint) {
        this.orderBasePoint = orderBasePoint;
    }

    public Long getBrandId() {
        return brandId;
    }

    public void setBrandId(Long brandId) {
        this.brandId = brandId;
    }

    public Date getOrderTime() {
        return orderTime;
    }

    public void setOrderTime(Date orderTime) {
        this.orderTime = orderTime;
    }

    public Integer getActivityType() {
        return activityType;
    }

    public void setActivityType(Integer activityType) {
        this.activityType = activityType;
    }

    public String getOrderNum() {
        return orderNum;
    }

    public void setOrderNum(String orderNum) {
        this.orderNum = orderNum;
    }

    public Date getBackOrderTime() {
        return backOrderTime;
    }

    public void setBackOrderTime(Date backOrderTime) {
        this.backOrderTime = backOrderTime;
    }

    public String getTag() {
        return tag;
    }

    public void setTag(String tag) {
        this.tag = tag;
    }

    public Long getMbrServiceStoreId() {
        return mbrServiceStoreId;
    }

    public void setMbrServiceStoreId(Long mbrServiceStoreId) {
        this.mbrServiceStoreId = mbrServiceStoreId;
    }

    public String getRemark() {
        return remark;
    }

    public void setRemark(String remark) {
        this.remark = remark;
    }
}

==> mktcenter-service-2.0.0-20200422.081715-46-sources.jar: com/bizvane/mktcenterservice/models/bo/OrderModelBo.java <==
package com.bizvane.mktcenterservice.models.bo;

import java.math.BigDecimal;
import java.util.Date;

/**
 * Created by agan on 2018/7/28.
 */
public class OrderModelBo {

    private String memberCode;//会员编号

    private Long brandId;//品牌id

    private Integer orderFrom;//订单来源

    private BigDecimal payMoney;//订单金额

    private String productNos;//商品编码

    private Long serviceStoreId;//服务门店id

    private Long mbrServiceStoreId;//服务门店id

    private Long levelId;//会员等级id

    private Integer memberType;//会员范围

    private Long companyId;//企业id

    private Integer orderBasePoint ;

    private Date orderTime;

    private Integer activityType;

    private String orderNum;

    //退单的订单时间
    private Date backOrderTime;

    private String tag;

    private String remark;

    private String  originalOrderNo;

    public Long getCompanyId() {
        return companyId;
    }

    public void setCompanyId(Long companyId) {
        this.companyId = companyId;
    }

    public String getProductNos() {
        return productNos;
    }

    public void setProductNos(String productNos) {
        this.productNos = productNos;
    }

    public Integer getMemberType() {
        return memberType;
    }

    public void setMemberType(Integer memberType) {
        this.memberType = memberType;
    }

    public BigDecimal getPayMoney() {
        return payMoney;
    }

    public void setPayMoney(BigDecimal payMoney) {
        this.payMoney = payMoney;
    }

    public String getMemberCode() {
        return memberCode;
    }

    public void setMemberCode(String memberCode) {
        this.memberCode = memberCode;
    }

    public Integer getOrderFrom() {
        return orderFrom;
    }

    public void setOrderFrom(Integer orderFrom) {
        this.orderFrom = orderFrom;
    }

    public Long getServiceStoreId() {
        return serviceStoreId;
    }

    public void setServiceStoreId(Long serviceStoreId) {
        this.serviceStoreId = serviceStoreId;
    }

    public Long getLevelId() {
        return levelId;
    }

    public void setLevelId(Long levelId) {
        this.levelId = levelId;
    }

    public Integer getOrderBasePoint() {
        return orderBasePoint;
    }

    public void setOrderBasePoint(Integer orderBasePoint) {
        this.orderBasePoint = orderBasePoint;
    }

    public Long getBrandId() {
        return brandId;
    }

    public void setBrandId(Long brandId) {
        this.brandId = brandId;
    }

    public Date getOrderTime() {
        return orderTime;
    }

    public void setOrderTime(Date orderTime) {
        this.orderTime = orderTime;
    }

    public Integer getActivityType() {
        return activityType;
    }

    public void setActivityType(Integer activityType) {
        this.activityType = activityType;
    }

    public String getOrderNum() {
        return orderNum;
    }

    public void setOrderNum(String orderNum) {
        this.orderNum = orderNum;
    }

    public Date getBackOrderTime() {
        return backOrderTime;
    }

    public void setBackOrderTime(Date backOrderTime) {
        this.backOrderTime = backOrderTime;
    }

    public String getTag() {
        return tag;
    }

    public void setTag(String tag) {
        this.tag = tag;
    }

    public Long getMbrServiceStoreId() {
        return mbrServiceStoreId;
    }

    public void setMbrServiceStoreId(Long mbrServiceStoreId) {
        this.mbrServiceStoreId = mbrServiceStoreId;
    }

    public String getRemark() {
        return remark;
    }

    public void setRemark(String remark) {
        this.remark = remark;
    }

    public String getOriginalOrderNo() {
        return originalOrderNo;
    }

    public void setOriginalOrderNo(String originalOrderNo) {
        this.originalOrderNo = originalOrderNo;
    }
}
